@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-10 14:40:50
-# @Last Modified time: 2021-02-08 14:05:54
+# @Last Modified time: 2021-03-08 14:05:21
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
@@ -45,6 +45,17 @@ class SqlMysqlCompile(SqlCompile):
         #     sql = f"{sql.replace(';', '')}interleaved sortkey({indexes});"
         return sql
 
+    def dumpsql(self, columns, dumpfile, fromtable=None, condition=None):
+        selectsql = self.select_base(columns, fromtable=None, condition=None)
+        intosql = f'into outfile "{dumpfile}" fields terminated by ",";'
+        dumpsql = selectsql.replace(";", intosql)
+        return dumpsql
+
+    def loadsql(self, columns, loadfile, intotable=None):
+        intotable = intotable or self.tablename
+        loadsql = f'load data infile "{loadfile}" into table {intotable} fields terminated by "," ({columns.select_cols});'
+        return loadsql
+
 
 class MysqlDB(DBCommon, DBFileExec):
     _instance_lock = threading.Lock()
@@ -80,3 +91,15 @@ class MysqlDB(DBCommon, DBFileExec):
         sql_for_create = sqlcompile.create(columns, indexes)
         rows, action, result = self.execute(sql_for_create, verbose=verbose)
         return rows, action, result
+
+    def dumpdata(self, tablename, columns, dumpfile, condition=None, verbose=0):
+        sqlcompile = SqlMysqlCompile(tablename)
+        sql_for_dump = sqlcompile.dumpsql(columns, dumpfile, condition=condition)
+        rows, action, result = self.execute(sql_for_dump, verbose=verbose)
+        return rows, action, result
+
+    def loaddata(self, tablename, columns, loadfile, verbose=0):
+        sqlcompile = SqlMysqlCompile(tablename)
+        sql_for_load = sqlcompile.loadsql(columns, loadfile)
+        rows, action, result = self.execute(sql_for_load, verbose=verbose)
+        return rows, action, result
